import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { HeliSabotageEvent } from "./HeliSabotageEvent";
import { Hostable } from "../../Hostable";
import { HeliSabotageSystem } from "../../systems";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player opens a heli sabotage console on Airship.
 */
export declare class HeliSabotageConsoleOpenEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, HeliSabotageEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly helisabotagesystem: HeliSabotageSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that opened the console.
     */
    readonly player: PlayerData<RoomType>;
    /**
     * The ID of the console that was opened.
     */
    readonly consoleId: number;
    static eventName: "heli.consoles.open";
    eventName: "heli.consoles.open";
    private _alteredConsoleId;
    private _alteredPlayer;
    constructor(room: RoomType, helisabotagesystem: HeliSabotageSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that opened the console.
     */
    player: PlayerData<RoomType>, 
    /**
     * The ID of the console that was opened.
     */
    consoleId: number);
    /**
     * The alternate ID of the console that will be opened, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * The alterenate player that will open the console, if changed.
     */
    get alteredPlayer(): PlayerData<RoomType>;
    /**
     * Change the ID of the console that was opened.
     * @param consoleId the ID of the conosle to open.
     */
    setConsoleId(consoleId: number): void;
    /**
     * Change the player that opened the console.
     * @param player The player to open the console.
     */
    setPlayer(player: PlayerData<RoomType>): void;
}
