import { BasicEvent } from "@skeldjs/events";
import { Color } from "@skeldjs/constant";
import { SetColorMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player has their player color updated.
 */
export declare class PlayerSetColorEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetColorMessage | undefined;
    /**
     * The color that the player had before.
     */
    readonly oldColor: Color;
    /**
     * The new color that the player has.
     */
    readonly newColor: Color;
    static eventName: "player.setcolor";
    eventName: "player.setcolor";
    private _alteredColor;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetColorMessage | undefined, 
    /**
     * The color that the player had before.
     */
    oldColor: Color, 
    /**
     * The new color that the player has.
     */
    newColor: Color);
    /**
     * The altered color that the player will have set instead, if changed.
     */
    get alteredColor(): Color;
    /**
     * Revert the player's color back to their old color.
     */
    revert(): void;
    /**
     * Change the color that the player had set.
     * @param color The color to set.
     */
    setColor(color: Color): void;
}
