"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Door = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Represents a manual door for the {@link DoorsSystem} or {@link ElectricalDoorsSystem}.
 *
 * See {@link DoorEvents} for events to listen to.
 */
class Door extends events_1.EventEmitter {
    constructor(system, doorId, isOpen) {
        super();
        this.system = system;
        this.doorId = doorId;
        this.isOpen = isOpen;
    }
    async emit(event) {
        if (this.system) {
            this.system.emit(event);
        }
        return super.emit(event);
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    Deserialize(reader, spawn) {
        this.isOpen = reader.bool(); // Use setter to emit events.
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    Serialize(writer, spawn) {
        writer.bool(this.isOpen);
    }
    async setOpen(isOpen) {
        if (isOpen === this.isOpen)
            return;
        if (isOpen) {
            await this.open();
        }
        else {
            await this.close();
        }
    }
    /**
     * Force the door open.
     */
    async open() {
        await this.system.openDoor(this.doorId);
    }
    /**
     * Force the door to close.
     */
    async close() {
        await this.system.closeDoor(this.doorId);
    }
}
exports.Door = Door;
//# sourceMappingURL=Door.js.map